summaryrefslogtreecommitdiff
path: root/sw/inc/fmtcolfunc.hxx
diff options
context:
space:
mode:
authorChristian Lohmaier <lohmaier+LibreOffice@googlemail.com>2015-05-20 13:05:49 +0200
committerChristian Lohmaier <lohmaier+LibreOffice@googlemail.com>2015-05-20 13:05:49 +0200
commitab465b90f6c6da5595393a0ba73f33a1e71a2b65 (patch)
tree36b77192de2799a11b4bf0b269cb3f74d0a0bb1f /sw/inc/fmtcolfunc.hxx
parent0db96caf0fcce09b87621c11b584a6d81cc7df86 (diff)
bin/rename-sw-abbreviations.shlibreoffice-5-0-branch-point
renames the most annoying abbreviations in Writer (and partially in the shared code too). Change-Id: I9a62759138126c1537cc5c985ba05cf54d6132d9
Diffstat (limited to 'sw/inc/fmtcolfunc.hxx')
-rw-r--r--sw/inc/fmtcolfunc.hxx24
1 files changed, 12 insertions, 12 deletions
diff --git a/sw/inc/fmtcolfunc.hxx b/sw/inc/fmtcolfunc.hxx
index e8b4771908c9..e6b12d0ef61b 100644
--- a/sw/inc/fmtcolfunc.hxx
+++ b/sw/inc/fmtcolfunc.hxx
@@ -19,12 +19,12 @@
#ifndef INCLUDED_SW_INC_FMTCOLFUNC_HXX
#define INCLUDED_SW_INC_FMTCOLFUNC_HXX
-class SwFmt;
+class SwFormat;
class SwNumRuleItem;
-// namespace <TxtFmtCollFunc> for functions and procedures working on
-// paragraph styles (instances of <SwTxtFmtColl>
-namespace TxtFmtCollFunc
+// namespace <TextFormatCollFunc> for functions and procedures working on
+// paragraph styles (instances of <SwTextFormatColl>
+namespace TextFormatCollFunc
{
/** Checks, if assignment of paragraph style to list level of outline style
has to be deleted, and deletes the assignment, if needed.
@@ -36,43 +36,43 @@ namespace TxtFmtCollFunc
@author OD
*/
- void CheckTxtFmtCollForDeletionOfAssignmentToOutlineStyle(
- SwFmt* pFmt,
+ void CheckTextFormatCollForDeletionOfAssignmentToOutlineStyle(
+ SwFormat* pFormat,
const SwNumRuleItem* pNewNumRuleItem = 0L );
/** determines the list style, which directly set at the given paragraph style
@author OD
- @param rTxtFmtColl
+ @param rTextFormatColl
input parameter - paragraph style for which the list style should be retrieved
@return pointer to <SwNumRule> instance, if the given paragraph style
has directly set a list style, 0 otherwise
*/
- SwNumRule* GetNumRule( SwTxtFmtColl& rTxtFmtColl );
+ SwNumRule* GetNumRule( SwTextFormatColl& rTextFormatColl );
/** adds the given paragraph style at the directly set list style
Note: If the given paragraph style has no directly set list style, nothing happens
- @param rTxtFmtColl
+ @param rTextFormatColl
input parameter - paragraph style which is added to its directly set list style
@author OD
*/
- void AddToNumRule( SwTxtFmtColl& rTxtFmtColl );
+ void AddToNumRule( SwTextFormatColl& rTextFormatColl );
/** removes te given paragraph style from the directly set list style
Note: If the given paragraph style has no directly set list style, nothing happens
- @param rTxtFmtColl
+ @param rTextFormatColl
input parameter - paragraph style which is removed from its directly set list style
@author OD
*/
- void RemoveFromNumRule( SwTxtFmtColl& rTxtFmtColl );
+ void RemoveFromNumRule( SwTextFormatColl& rTextFormatColl );
}
#endif